@@ -981,10 +981,20 @@ var _ = Describe("Reconcile steps", func() {
 				return nil
 			}
 
+			annotations := make(map[string]string)
+			annotations[AnnDVNetwork] = "annDVNetwork"
+			annotations[AnnDVMultusNetwork] = "annDVMultusNetwork"
+			instance.SetAnnotations(annotations)
+
 			dv := cdiv1.DataVolume{}
 			_, err := reconciler.createDataVolume(mock, mapper, instance, &dv, vmName)
 
 			Expect(err).To(BeNil())
+
+			// ensure that DV transfer network annotations were propagated from VMI to DVs
+			Expect(dv.Annotations).ToNot(BeNil())
+			Expect(dv.Annotations[AnnDVNetwork]).To(Equal("annDVNetwork"))
+			Expect(dv.Annotations[AnnDVMultusNetwork]).To(Equal("annDVMultusNetwork"))
 		})
 	})
 
@@ -1679,7 +1689,7 @@ var _ = Describe("Reconcile steps", func() {
 			Expect(event).To(ContainSubstring("ImportInProgress"))
 
 			Expect(err).To(BeNil())
-			Expect(result).To(Equal(reconcile.Result{}))
+			Expect(result).To(Equal(reconcile.Result{RequeueAfter: SlowReQ}))
 		})
 
 		It("should fail to start vm: ", func() {
@@ -1728,7 +1738,7 @@ var _ = Describe("Reconcile steps", func() {
 			result, err := reconciler.Reconcile(request)
 
 			Expect(err).To(BeNil())
-			Expect(result).To(Equal(reconcile.Result{}))
+			Expect(result).To(Equal(reconcile.Result{RequeueAfter: SlowReQ}))
 		})
 
 		It("should exit early if vm condition is succeed: ", func() {
@@ -1854,7 +1864,8 @@ var _ = Describe("Reconcile steps", func() {
 				result, err := reconciler.Reconcile(request)
 
 				Expect(err).To(BeNil())
-				Expect(result).To(Equal(reconcile.Result{}))
+
+				Expect(result).To(Equal(reconcile.Result{RequeueAfter: SlowReQ}))
 				Expect(config.Finalizers).To(Not(BeNil()))
 				Expect(config.Annotations[AnnCurrentProgress]).To(Not(BeNil()))
 
